<!--标识牌区域分析统计-->
<template>
  <div class="alarm-data-statistics">
    <public-title title="标识牌区域分析统计" />
    <div class="chart-container">
      <div id="alarm-data-statistics-chart" style="width: 100%;height: 100%;" />
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {alarmStatisticsAnalysis} from '@/api/device/earlyWarningMonitoring'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'AlarmDataStatistics',
  components: {PublicTitle},
  data() {
    return {
      myChart: null,  // 图表实例对象
      historyArr: [] // 下钻数据历史
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('alarm-data-statistics-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    async getChartData() {
      const {value} = await alarmStatisticsAnalysis('1')
      this.chartData = value
      this.$nextTick(_ => this.initEcharts())
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        tooltip: {
          trigger: 'axis',
          textStyle: {  //---提示框样式
            color: '#606266',
            fontSize: '14'
          },
          axisPointer: {            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
          }
        },
        legend: {
          type: 'plain',
          position: 'center',
          textStyle: {  //---提示框样式
            color: '#606266',
            fontSize: '14'
          }
        },
        grid: {
          left: '0',
          right: '0',
          bottom: '0',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            axisTick: {show: true},
            axisLabel: {color: '#606266', fontSize: '14', interval: 0},
            data: this.chartData.map(i => i.name)
          }
        ],
        yAxis: [
          {
            type: 'value',
            name: '单位（件数）',
            nameTextStyle: {
              color: '#606266',
              fontSize: '14',
              align: 'end',
              padding: [0, 0, 0, -10]
            },
            nameGap: 30,
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {color: '#606266', fontSize: '14'},
            // 修改y轴分割线
            splitLine: {
              lineStyle: {
                color: '#c7c7c7',
                fontSize: '14',
                type: 'dashed'
              }
            }
          }
        ],
        series: [
          {
            name: '已处理数',
            type: 'bar',
            barGap: '20%',
            barWidth: '30',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#3eadfd'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#3eadfd',//字体颜色
                fontSize: 12//字体大小
              }
            },
            data: this.chartData.map(i => i.alearnNum)
          },
          {
            name: '未处理数',
            type: 'bar',
            barGap: '20%',
            barWidth: '30',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#ff6e79'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#ff6e79',//字体颜色
                fontSize: 12//字体大小
              }
            },
            data: this.chartData.map(i => i.notNum)
          },
          {
            name: '事件总数',
            type: 'line',
            itemStyle: {
              color: '#42ffe8'
            },
            data: this.chartData.map(i => i.total)
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.alarm-data-statistics {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }
}
</style>
